import { SENSITIVE_STRING, } from "@smithy/smithy-client";
import { LexRuntimeServiceServiceException as __BaseException } from "./LexRuntimeServiceServiceException";
export class BadRequestException extends __BaseException {
    name = "BadRequestException";
    $fault = "client";
    constructor(opts) {
        super({
            name: "BadRequestException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, BadRequestException.prototype);
    }
}
export class ConflictException extends __BaseException {
    name = "ConflictException";
    $fault = "client";
    constructor(opts) {
        super({
            name: "ConflictException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, ConflictException.prototype);
    }
}
export class InternalFailureException extends __BaseException {
    name = "InternalFailureException";
    $fault = "server";
    constructor(opts) {
        super({
            name: "InternalFailureException",
            $fault: "server",
            ...opts,
        });
        Object.setPrototypeOf(this, InternalFailureException.prototype);
    }
}
export class LimitExceededException extends __BaseException {
    name = "LimitExceededException";
    $fault = "client";
    retryAfterSeconds;
    constructor(opts) {
        super({
            name: "LimitExceededException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, LimitExceededException.prototype);
        this.retryAfterSeconds = opts.retryAfterSeconds;
    }
}
export class NotFoundException extends __BaseException {
    name = "NotFoundException";
    $fault = "client";
    constructor(opts) {
        super({
            name: "NotFoundException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, NotFoundException.prototype);
    }
}
export const FulfillmentState = {
    FAILED: "Failed",
    FULFILLED: "Fulfilled",
    READY_FOR_FULFILLMENT: "ReadyForFulfillment",
};
export const MessageFormatType = {
    COMPOSITE: "Composite",
    CUSTOM_PAYLOAD: "CustomPayload",
    PLAIN_TEXT: "PlainText",
    SSML: "SSML",
};
export const DialogActionType = {
    CLOSE: "Close",
    CONFIRM_INTENT: "ConfirmIntent",
    DELEGATE: "Delegate",
    ELICIT_INTENT: "ElicitIntent",
    ELICIT_SLOT: "ElicitSlot",
};
export const ConfirmationStatus = {
    CONFIRMED: "Confirmed",
    DENIED: "Denied",
    NONE: "None",
};
export class BadGatewayException extends __BaseException {
    name = "BadGatewayException";
    $fault = "server";
    Message;
    constructor(opts) {
        super({
            name: "BadGatewayException",
            $fault: "server",
            ...opts,
        });
        Object.setPrototypeOf(this, BadGatewayException.prototype);
        this.Message = opts.Message;
    }
}
export class DependencyFailedException extends __BaseException {
    name = "DependencyFailedException";
    $fault = "client";
    Message;
    constructor(opts) {
        super({
            name: "DependencyFailedException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, DependencyFailedException.prototype);
        this.Message = opts.Message;
    }
}
export class LoopDetectedException extends __BaseException {
    name = "LoopDetectedException";
    $fault = "server";
    Message;
    constructor(opts) {
        super({
            name: "LoopDetectedException",
            $fault: "server",
            ...opts,
        });
        Object.setPrototypeOf(this, LoopDetectedException.prototype);
        this.Message = opts.Message;
    }
}
export class NotAcceptableException extends __BaseException {
    name = "NotAcceptableException";
    $fault = "client";
    constructor(opts) {
        super({
            name: "NotAcceptableException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, NotAcceptableException.prototype);
    }
}
export const DialogState = {
    CONFIRM_INTENT: "ConfirmIntent",
    ELICIT_INTENT: "ElicitIntent",
    ELICIT_SLOT: "ElicitSlot",
    FAILED: "Failed",
    FULFILLED: "Fulfilled",
    READY_FOR_FULFILLMENT: "ReadyForFulfillment",
};
export class RequestTimeoutException extends __BaseException {
    name = "RequestTimeoutException";
    $fault = "client";
    constructor(opts) {
        super({
            name: "RequestTimeoutException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, RequestTimeoutException.prototype);
    }
}
export class UnsupportedMediaTypeException extends __BaseException {
    name = "UnsupportedMediaTypeException";
    $fault = "client";
    constructor(opts) {
        super({
            name: "UnsupportedMediaTypeException",
            $fault: "client",
            ...opts,
        });
        Object.setPrototypeOf(this, UnsupportedMediaTypeException.prototype);
    }
}
export const ContentType = {
    GENERIC: "application/vnd.amazonaws.card.generic",
};
export const ActiveContextFilterSensitiveLog = (obj) => ({
    ...obj,
    ...(obj.parameters && { parameters: SENSITIVE_STRING }),
});
export const DialogActionFilterSensitiveLog = (obj) => ({
    ...obj,
    ...(obj.slots && { slots: SENSITIVE_STRING }),
    ...(obj.message && { message: SENSITIVE_STRING }),
});
export const IntentSummaryFilterSensitiveLog = (obj) => ({
    ...obj,
    ...(obj.slots && { slots: SENSITIVE_STRING }),
});
export const GetSessionResponseFilterSensitiveLog = (obj) => ({
    ...obj,
    ...(obj.recentIntentSummaryView && {
        recentIntentSummaryView: obj.recentIntentSummaryView.map((item) => IntentSummaryFilterSensitiveLog(item)),
    }),
    ...(obj.sessionAttributes && { sessionAttributes: SENSITIVE_STRING }),
    ...(obj.dialogAction && { dialogAction: DialogActionFilterSensitiveLog(obj.dialogAction) }),
    ...(obj.activeContexts && { activeContexts: SENSITIVE_STRING }),
});
export const PostContentRequestFilterSensitiveLog = (obj) => ({
    ...obj,
    ...(obj.sessionAttributes && { sessionAttributes: SENSITIVE_STRING }),
    ...(obj.requestAttributes && { requestAttributes: SENSITIVE_STRING }),
    ...(obj.activeContexts && { activeContexts: SENSITIVE_STRING }),
});
export const PostContentResponseFilterSensitiveLog = (obj) => ({
    ...obj,
    ...(obj.message && { message: SENSITIVE_STRING }),
    ...(obj.encodedMessage && { encodedMessage: SENSITIVE_STRING }),
    ...(obj.encodedInputTranscript && { encodedInputTranscript: SENSITIVE_STRING }),
    ...(obj.activeContexts && { activeContexts: SENSITIVE_STRING }),
});
export const PostTextRequestFilterSensitiveLog = (obj) => ({
    ...obj,
    ...(obj.sessionAttributes && { sessionAttributes: SENSITIVE_STRING }),
    ...(obj.requestAttributes && { requestAttributes: SENSITIVE_STRING }),
    ...(obj.inputText && { inputText: SENSITIVE_STRING }),
    ...(obj.activeContexts && { activeContexts: SENSITIVE_STRING }),
});
export const PredictedIntentFilterSensitiveLog = (obj) => ({
    ...obj,
    ...(obj.slots && { slots: SENSITIVE_STRING }),
});
export const PostTextResponseFilterSensitiveLog = (obj) => ({
    ...obj,
    ...(obj.alternativeIntents && {
        alternativeIntents: obj.alternativeIntents.map((item) => PredictedIntentFilterSensitiveLog(item)),
    }),
    ...(obj.slots && { slots: SENSITIVE_STRING }),
    ...(obj.sessionAttributes && { sessionAttributes: SENSITIVE_STRING }),
    ...(obj.message && { message: SENSITIVE_STRING }),
    ...(obj.activeContexts && { activeContexts: SENSITIVE_STRING }),
});
export const PutSessionRequestFilterSensitiveLog = (obj) => ({
    ...obj,
    ...(obj.sessionAttributes && { sessionAttributes: SENSITIVE_STRING }),
    ...(obj.dialogAction && { dialogAction: DialogActionFilterSensitiveLog(obj.dialogAction) }),
    ...(obj.recentIntentSummaryView && {
        recentIntentSummaryView: obj.recentIntentSummaryView.map((item) => IntentSummaryFilterSensitiveLog(item)),
    }),
    ...(obj.activeContexts && { activeContexts: SENSITIVE_STRING }),
});
export const PutSessionResponseFilterSensitiveLog = (obj) => ({
    ...obj,
    ...(obj.message && { message: SENSITIVE_STRING }),
    ...(obj.encodedMessage && { encodedMessage: SENSITIVE_STRING }),
    ...(obj.activeContexts && { activeContexts: SENSITIVE_STRING }),
});
