import {
  AutomaticJsonStringConversion as __AutomaticJsonStringConversion,
  ExceptionOptionType as __ExceptionOptionType,
} from "@smithy/smithy-client";
import { StreamingBlobTypes } from "@smithy/types";
import { LexRuntimeServiceServiceException as __BaseException } from "./LexRuntimeServiceServiceException";
export interface ActiveContextTimeToLive {
  timeToLiveInSeconds?: number | undefined;
  turnsToLive?: number | undefined;
}
export interface ActiveContext {
  name: string | undefined;
  timeToLive: ActiveContextTimeToLive | undefined;
  parameters: Record<string, string> | undefined;
}
export declare class BadRequestException extends __BaseException {
  readonly name: "BadRequestException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<BadRequestException, __BaseException>
  );
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export interface DeleteSessionRequest {
  botName: string | undefined;
  botAlias: string | undefined;
  userId: string | undefined;
}
export interface DeleteSessionResponse {
  botName?: string | undefined;
  botAlias?: string | undefined;
  userId?: string | undefined;
  sessionId?: string | undefined;
}
export declare class InternalFailureException extends __BaseException {
  readonly name: "InternalFailureException";
  readonly $fault: "server";
  constructor(
    opts: __ExceptionOptionType<InternalFailureException, __BaseException>
  );
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  retryAfterSeconds?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export declare class NotFoundException extends __BaseException {
  readonly name: "NotFoundException";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<NotFoundException, __BaseException>);
}
export interface GetSessionRequest {
  botName: string | undefined;
  botAlias: string | undefined;
  userId: string | undefined;
  checkpointLabelFilter?: string | undefined;
}
export declare const FulfillmentState: {
  readonly FAILED: "Failed";
  readonly FULFILLED: "Fulfilled";
  readonly READY_FOR_FULFILLMENT: "ReadyForFulfillment";
};
export type FulfillmentState =
  (typeof FulfillmentState)[keyof typeof FulfillmentState];
export declare const MessageFormatType: {
  readonly COMPOSITE: "Composite";
  readonly CUSTOM_PAYLOAD: "CustomPayload";
  readonly PLAIN_TEXT: "PlainText";
  readonly SSML: "SSML";
};
export type MessageFormatType =
  (typeof MessageFormatType)[keyof typeof MessageFormatType];
export declare const DialogActionType: {
  readonly CLOSE: "Close";
  readonly CONFIRM_INTENT: "ConfirmIntent";
  readonly DELEGATE: "Delegate";
  readonly ELICIT_INTENT: "ElicitIntent";
  readonly ELICIT_SLOT: "ElicitSlot";
};
export type DialogActionType =
  (typeof DialogActionType)[keyof typeof DialogActionType];
export interface DialogAction {
  type: DialogActionType | undefined;
  intentName?: string | undefined;
  slots?: Record<string, string> | undefined;
  slotToElicit?: string | undefined;
  fulfillmentState?: FulfillmentState | undefined;
  message?: string | undefined;
  messageFormat?: MessageFormatType | undefined;
}
export declare const ConfirmationStatus: {
  readonly CONFIRMED: "Confirmed";
  readonly DENIED: "Denied";
  readonly NONE: "None";
};
export type ConfirmationStatus =
  (typeof ConfirmationStatus)[keyof typeof ConfirmationStatus];
export interface IntentSummary {
  intentName?: string | undefined;
  checkpointLabel?: string | undefined;
  slots?: Record<string, string> | undefined;
  confirmationStatus?: ConfirmationStatus | undefined;
  dialogActionType: DialogActionType | undefined;
  fulfillmentState?: FulfillmentState | undefined;
  slotToElicit?: string | undefined;
}
export interface GetSessionResponse {
  recentIntentSummaryView?: IntentSummary[] | undefined;
  sessionAttributes?: Record<string, string> | undefined;
  sessionId?: string | undefined;
  dialogAction?: DialogAction | undefined;
  activeContexts?: ActiveContext[] | undefined;
}
export declare class BadGatewayException extends __BaseException {
  readonly name: "BadGatewayException";
  readonly $fault: "server";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<BadGatewayException, __BaseException>
  );
}
export declare class DependencyFailedException extends __BaseException {
  readonly name: "DependencyFailedException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<DependencyFailedException, __BaseException>
  );
}
export declare class LoopDetectedException extends __BaseException {
  readonly name: "LoopDetectedException";
  readonly $fault: "server";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<LoopDetectedException, __BaseException>
  );
}
export declare class NotAcceptableException extends __BaseException {
  readonly name: "NotAcceptableException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<NotAcceptableException, __BaseException>
  );
}
export interface PostContentRequest {
  botName: string | undefined;
  botAlias: string | undefined;
  userId: string | undefined;
  sessionAttributes?: __AutomaticJsonStringConversion | string | undefined;
  requestAttributes?: __AutomaticJsonStringConversion | string | undefined;
  contentType: string | undefined;
  accept?: string | undefined;
  inputStream: StreamingBlobTypes | undefined;
  activeContexts?: __AutomaticJsonStringConversion | string | undefined;
}
export declare const DialogState: {
  readonly CONFIRM_INTENT: "ConfirmIntent";
  readonly ELICIT_INTENT: "ElicitIntent";
  readonly ELICIT_SLOT: "ElicitSlot";
  readonly FAILED: "Failed";
  readonly FULFILLED: "Fulfilled";
  readonly READY_FOR_FULFILLMENT: "ReadyForFulfillment";
};
export type DialogState = (typeof DialogState)[keyof typeof DialogState];
export interface PostContentResponse {
  contentType?: string | undefined;
  intentName?: string | undefined;
  nluIntentConfidence?: __AutomaticJsonStringConversion | string | undefined;
  alternativeIntents?: __AutomaticJsonStringConversion | string | undefined;
  slots?: __AutomaticJsonStringConversion | string | undefined;
  sessionAttributes?: __AutomaticJsonStringConversion | string | undefined;
  sentimentResponse?: string | undefined;
  message?: string | undefined;
  encodedMessage?: string | undefined;
  messageFormat?: MessageFormatType | undefined;
  dialogState?: DialogState | undefined;
  slotToElicit?: string | undefined;
  inputTranscript?: string | undefined;
  encodedInputTranscript?: string | undefined;
  audioStream?: StreamingBlobTypes | undefined;
  botVersion?: string | undefined;
  sessionId?: string | undefined;
  activeContexts?: __AutomaticJsonStringConversion | string | undefined;
}
export declare class RequestTimeoutException extends __BaseException {
  readonly name: "RequestTimeoutException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<RequestTimeoutException, __BaseException>
  );
}
export declare class UnsupportedMediaTypeException extends __BaseException {
  readonly name: "UnsupportedMediaTypeException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<UnsupportedMediaTypeException, __BaseException>
  );
}
export interface PostTextRequest {
  botName: string | undefined;
  botAlias: string | undefined;
  userId: string | undefined;
  sessionAttributes?: Record<string, string> | undefined;
  requestAttributes?: Record<string, string> | undefined;
  inputText: string | undefined;
  activeContexts?: ActiveContext[] | undefined;
}
export interface IntentConfidence {
  score?: number | undefined;
}
export interface PredictedIntent {
  intentName?: string | undefined;
  nluIntentConfidence?: IntentConfidence | undefined;
  slots?: Record<string, string> | undefined;
}
export declare const ContentType: {
  readonly GENERIC: "application/vnd.amazonaws.card.generic";
};
export type ContentType = (typeof ContentType)[keyof typeof ContentType];
export interface Button {
  text: string | undefined;
  value: string | undefined;
}
export interface GenericAttachment {
  title?: string | undefined;
  subTitle?: string | undefined;
  attachmentLinkUrl?: string | undefined;
  imageUrl?: string | undefined;
  buttons?: Button[] | undefined;
}
export interface ResponseCard {
  version?: string | undefined;
  contentType?: ContentType | undefined;
  genericAttachments?: GenericAttachment[] | undefined;
}
export interface SentimentResponse {
  sentimentLabel?: string | undefined;
  sentimentScore?: string | undefined;
}
export interface PostTextResponse {
  intentName?: string | undefined;
  nluIntentConfidence?: IntentConfidence | undefined;
  alternativeIntents?: PredictedIntent[] | undefined;
  slots?: Record<string, string> | undefined;
  sessionAttributes?: Record<string, string> | undefined;
  message?: string | undefined;
  sentimentResponse?: SentimentResponse | undefined;
  messageFormat?: MessageFormatType | undefined;
  dialogState?: DialogState | undefined;
  slotToElicit?: string | undefined;
  responseCard?: ResponseCard | undefined;
  sessionId?: string | undefined;
  botVersion?: string | undefined;
  activeContexts?: ActiveContext[] | undefined;
}
export interface PutSessionRequest {
  botName: string | undefined;
  botAlias: string | undefined;
  userId: string | undefined;
  sessionAttributes?: Record<string, string> | undefined;
  dialogAction?: DialogAction | undefined;
  recentIntentSummaryView?: IntentSummary[] | undefined;
  accept?: string | undefined;
  activeContexts?: ActiveContext[] | undefined;
}
export interface PutSessionResponse {
  contentType?: string | undefined;
  intentName?: string | undefined;
  slots?: __AutomaticJsonStringConversion | string | undefined;
  sessionAttributes?: __AutomaticJsonStringConversion | string | undefined;
  message?: string | undefined;
  encodedMessage?: string | undefined;
  messageFormat?: MessageFormatType | undefined;
  dialogState?: DialogState | undefined;
  slotToElicit?: string | undefined;
  audioStream?: StreamingBlobTypes | undefined;
  sessionId?: string | undefined;
  activeContexts?: __AutomaticJsonStringConversion | string | undefined;
}
export declare const ActiveContextFilterSensitiveLog: (
  obj: ActiveContext
) => any;
export declare const DialogActionFilterSensitiveLog: (obj: DialogAction) => any;
export declare const IntentSummaryFilterSensitiveLog: (
  obj: IntentSummary
) => any;
export declare const GetSessionResponseFilterSensitiveLog: (
  obj: GetSessionResponse
) => any;
export declare const PostContentRequestFilterSensitiveLog: (
  obj: PostContentRequest
) => any;
export declare const PostContentResponseFilterSensitiveLog: (
  obj: PostContentResponse
) => any;
export declare const PostTextRequestFilterSensitiveLog: (
  obj: PostTextRequest
) => any;
export declare const PredictedIntentFilterSensitiveLog: (
  obj: PredictedIntent
) => any;
export declare const PostTextResponseFilterSensitiveLog: (
  obj: PostTextResponse
) => any;
export declare const PutSessionRequestFilterSensitiveLog: (
  obj: PutSessionRequest
) => any;
export declare const PutSessionResponseFilterSensitiveLog: (
  obj: PutSessionResponse
) => any;
